import bpy 

bl_info = {
    "name": "QPP : Quick Prop Panel",
    "description": "Common used functions on single panel",
    "author": "B3D Team",
    "version": (1, 0, 0),
    "blender": (3, 0, 0),
    "location": "View 3D > Properties",
    "wiki_url": "https://www.facebook.com/groups/blenderworld/",
    "tracker_url": "",
    "support": "COMMUNITY",
    "category": "Add Mesh"
}

### RENDERING ### 
class QPP_PanelRendering(bpy.types.Panel):
    bl_label = "QPP : Quick Prop Panel"
    bl_space_type = 'VIEW_3D'
    bl_region_type = 'UI'
    bl_category = "QPP"
    bl_options = {'DEFAULT_CLOSED'}    

    def draw(self, context):
        layout = self.layout
        scene = context.scene
        cscene = scene.cycles
        rd = scene.render
               
        row = layout.row(align=True)
        row.label(text="Rendering", icon="RESTRICT_RENDER_OFF")
        row = layout.row(align=True)
        if rd.has_multiple_engines:
            row.prop(rd, "engine", text="")
        row = layout.row(align=True)
        row.operator("render.render", text="Render", icon='RENDER_STILL')
        row.operator("render.render", text="Animation", icon='RENDER_ANIMATION').animation = True
        row = layout.row(align=True)
        row.prop(rd, "resolution_x", text="X")
        row.prop(rd, "resolution_y", text="Y")
        row = layout.row(align=True)
        row.prop(rd, "resolution_percentage", text="")
        row = layout.row(align=True)
        row.prop(rd, "film_transparent", text="Transparent Background")
        row = layout.row(align=True)
        row.prop(rd, "use_border", text="Render Region")
        row = layout.row(align=True)
        row.label(text="Cycles Render Denoising", icon="NODE_MATERIAL")
        row = layout.row(align=True)
        row.prop(cscene, "use_denoising", text="")
        sub = row.row()

        sub.active = cscene.use_denoising
        for view_layer in scene.view_layers:
            if view_layer.cycles.denoising_store_passes:
                sub.active = True
        sub.prop(cscene, "denoiser", text="")
        
        row = layout.row(align=True)
        row.label(text="Cycles Viewport Denoising", icon="OUTLINER_OB_META")
        row = layout.row(align=False, heading="")
        row.prop(cscene, "use_preview_denoising", text="")
        row.active = cscene.use_preview_denoising

        row.prop(cscene, "preview_denoiser", text="")
        row = layout.row(align=True)
        row.active = cscene.use_preview_denoising
        row.prop(cscene, "preview_denoising_start_sample", text="Start Sample")
        
        obj = context.object


        if obj: 
            row = layout.row(align=True)
            row.label(text="Material")
            row = layout.row(align=True)
            row.template_ID(obj, "active_material", new="material.new")
            row = layout.row(align=True)

            row.label(text="Viewport Color:")
            if obj.active_material:
                row.prop(obj.active_material, "diffuse_color", text="") 
            row = layout.row(align=True)
            row.operator("object.material_slot_copy", text="Copy Material to Selected", icon="FORWARD")


        tool_settings = context.tool_settings
        snap_elements = tool_settings.snap_elements
        obj = context.object
        object_mode = 'OBJECT' if obj is None else obj.mode
        
        layout = self.layout
        row = layout.row(align=True)
        row.label(text="Snapping", icon="SNAP_FACE_CENTER")
        row = layout.row(align=True)
        row.prop(tool_settings, "snap_elements", expand=True)

### TRANSFORM PIVOT ###
        layout = self.layout
        row = layout.row(align=True)
        row.label(text="Transform Pivot Point", icon="PIVOT_BOUNDBOX")
        row = layout.row(align=True)
        row.prop_enum(context.scene.tool_settings, "transform_pivot_point", value='BOUNDING_BOX_CENTER')
        row.prop_enum(context.scene.tool_settings, "transform_pivot_point", value='CURSOR')
        row.prop_enum(context.scene.tool_settings, "transform_pivot_point", value='INDIVIDUAL_ORIGINS')
        
### GIZMOS ###     
        scene = context.scene
        view = context.space_data
        
        row = layout.row(align=True)
        row.label(text="Object Gizmos", icon="OUTLINER_OB_EMPTY")
        row = layout.row(align=True)
        row.prop(view, "show_gizmo_object_translate", text="Move")
        row.prop(view, "show_gizmo_object_rotate", text="Rotate")
        row.prop(view, "show_gizmo_object_scale", text="Scale")

### OBJECT TRANSFORM ###
        obj = context.active_object
        if obj:      
            layout = self.layout
            split = layout.split(align=True)
            col = split.column(align=True)
            col.label(text="Object Transform")
            col.prop(context.object, "location", text="Location")
            col = split.column(align=True)
            col.label(text="")
            col.prop(context.object, "rotation_euler", text="Rotation")
            split = layout.split(align=True)
            col = split.column(align=True)
            col.prop(context.object, "scale", text="Scale")
            col = split.column(align=True)
            col.prop(context.object, "dimensions", text="Dimensions")
        

### VIEWPORT CLIPPING ###
        split = layout.split(align=True)
        col = split.column(align=True)
        col.label(text="Viewport Clipping")
        col.prop(context.space_data, "clip_start", text="Start")
        col = split.column(align=True)
        col.label(text=" ")
        col.prop(context.space_data, "clip_end", text="End")
        row = layout.row(align=True)
        row.prop(context.space_data, "lens", text="Focal Lenght")

### SAVE SETTINGS / STARTUP FILE ###        
        row = layout.row(align=True)
        row = layout.row()
        row.operator("wm.save_homefile", text="Save Setting / StartUp File")
        row = layout.row()
        row.label(text="B3D Blender Ubgrade V1.0")


### END WORD - SILENCE IS GOLDEN ### 
      
        
def register():
    bpy.utils.register_class(QPP_PanelRendering)

    
def unregister():
    bpy.utils.unregister_class(QPP_PanelRendering)




if __name__ == "__main__":
    register()
    